<?php

class SubDomain {
  
  var $domain;
  var $host;
  var $host_old;
  var $customer;
  
  var $virtualHost;
  var $port;
  var $serverAdmin;
  var $serverName;
  var $serverAlias;
  var $scriptAlias;
  var $documentRoot;
  var $errorLog;
  var $customLog;
  var $transferLog;

/**
 * @return class object SubDomain
 * @desc creates an object SubDomain and sets the default values
*/ 
  function SubDomain() {
    $this->reset(); 
  }
  
/**
 * @param hostname of the subdomain which should be created
 * @desc Set host and on host depending values like ServerName, ServerAlias and Logfiles
*/
  function setHost($host) {
    $this->host_old = $this->host;
    $this->host = $host;
    $this->serverName = $this->host . "." . $this->domain;
    if ($this->host != "www") {
      $this->serverAlias = "www." . $this->host ."." . $this->domain;
    } else {
      $this->serverAlias = $this->domain;
    }
    
    $logdir = pmwh_getOption('logdir');
    
    $this->errorLog = $logdir . $this->domain . "." . $this->host . "-error.log";
    $this->customLog = $logdir . $this->domain . "." . $this->host . "-access.log";
    $this->transferLog = $logdir . $this->domain . "." . $this->host . "-transfer.log";
  }
  
/**
 * @desc Creates a new subdomain. Class function setHost($host) need to be run before inserting
*/
  function insert() {
    $query = "select * from domains where data like '%ServerName ".$this->host.".".$this->domain."%'";
    if (sql_rows($query) > 0) {
      $content = array(_HOST_ALREADY_CREATED);
      $url = "act=apache&what=show&show=" . ($_POST['show'] ? $_POST['show'] : $_GET['show']);
    } elseif ($this->host != "") {
      $vhost_data = "<VirtualHost ". $this->virtualHost .":" . $this->port . ">
ServerAdmin " . $this->serverAdmin . "
ServerName " . $this->serverName . "
ServerAlias " . $this->serverAlias . "
ScriptAlias " . $this->scriptAlias . "
DocumentRoot " . $this->documentRoot . $this->host . "/
ErrorLog " . $this->errorLog . "
CustomLog " . $this->customLog . " full
TransferLog " . $this->transferLog . "
</VirtualHost>";
      $query = "insert into domains (domain,customer,data) values ('".$this->host . "." . $this->domain."','".$this->customer."','".$vhost_data."')";
      if (sql_query($query)) {
        $content = array(_SUBDOMAIN_SAVED);
        $url = "act=apache&what=show&show=" . ($_POST['show'] ? $_POST['show'] : $_GET['show']);
        if (!file_exists(pmwh_getOption("webroot") . $this->domain . "/" . $this->host)) {
        	if (is_writable(pmwh_getOption("webroot") . $this->domain . "/")) {
	        	mkdir(pmwh_getOption("webroot") . $this->domain . "/" . $this->host);
	        	chmod(pmwh_getOption("webroot") . $this->domain . "/" . $this->host,777);
        	}
        }
      } else {
        $content = array(_SAVE_ABORT);
        $url = "act=apache&what=show&show=" . ($_POST['show'] ? $_POST['show'] : $_GET['show']);
      }
    } else {
      $content = array(_NO_HOST_GIVEN);
      $url = "act=apache&what=newsub&show=" . ($_POST['show'] ? $_POST['show'] : $_GET['show']);
    }
    infoBox($content,$url);
  } 

/**
 * @desc Updates a subdomain. Class function get($domain) and setHost($host) need to be run before updating
*/
  function update() {
    $query = "select * from domains where data like 'ServerName ".$this->host_old.".".$this->domain."'";
    $url = "act=apache&what=show&show=" . $this->domain;
    if (sql_rows($query) > 0) {
      $content = array(_HOST_NOT_IN_DB);
    } elseif ($this->host == "") {
      $content = array(_NO_HOST_SPECIFIED);
    } else {
      $vhost_data = "<VirtualHost ". $this->virtualHost .":" . $this->port . ">
ServerAdmin " . $this->serverAdmin . "
ServerName " . $this->serverName . "
ServerAlias " . $this->serverAlias . "
ScriptAlias " . $this->scriptAlias . "
DocumentRoot " . $this->documentRoot . $this->host . "/
ErrorLog " . $this->errorLog . "
CustomLog " . $this->customLog . " full
TransferLog " . $this->transferLog . "
</VirtualHost>";
      $query = "update domains set domain='".$this->host . "." . $this->domain ."', data ='". $vhost_data ."' where domain = '".$this->host_old . "." . $this->domain ."'";
      if (sql_query($query)) {
        $content = array(_SAVE_SUCCESSFUL);
      } else {
        $content = array(_SAVE_ABORT);
      }
    }
    infoBox($content,$url);
  }

/**
 * @return class object SubDomain with database entries set
 * @param $full_qualified_domain_name
 * @desc gets values from database and sets the values domain, customer and all values which are included in data
*/
  function get($fqdn) {
   $query = "select * from domains where domain='".$fqdn."'";
    $result = sql_query($query);
    $row = sql_fetch_assoc($result);
    while (list($key,$value) = each($row)) {
      if ($key == "domain") {
      	if (preg_match("/^([0-9a-zA-Z\-]+)\.([0-9a-zA-Z\-]+\.[a-zA-Z\-]+)$/",$value,$match)) {
          $this->host = $match[1];
	      $this->domain = $match[2];
      	} else {
      	  $this->domain = $value;
      	}
      }
      if ($key == "customer") {
        $this->customer = $value;
      }
      if ($key == "data") {
        $daten = split("\n",$value);
        while (list(,$val) = each($daten)) {
          if (!preg_match("/<\/VirtualHost>/",$val)) {
            $val = preg_replace("/^\s*<?/","",$val);
            $val = preg_replace("/>$/","",$val);
            if (!preg_match("/^(Script)?Alias/",$val)) {
              list($k,$v) = split(" ",$val);
            }
            $this->$k = $v;
          }
        }
      }
    } 
  }

  function getAll() {
  	if (_ISADMIN == "Y") {
  		$query = "select domain from domains where domain like '%.".$this->domain."' order by domain";
  	} else {
    	$query = "select domain from domains where customer='".$this->customer."' and domain like '%.".$this->domain."' order by domain";
  	}
    $result = sql_query($query);
    $domains = array();
    while (list($dom) = sql_fetch_row($result)) {
      $domains[] = "$dom";
    }
    return $domains;
  }
  
  function delete() {
    $url = "act=apache&what=show&show=" . $this->domain;
    if ($this->domain != "") {
      $query = "delete from domains where domain='".$this->host . "." . $this->domain."'";
      if (sql_query($query)) {
        $content = array(_DELETE_SUCCESSFUL);
        if (file_exists(pmwh_getOption("webroot") . $this->domain . "/" . $this->host)) {
        	if (is_writable(pmwh_getOption("webroot") . $this->domain . "/")) {
	        	rmdir(pmwh_getOption("webroot") . $this->domain . "/" . $this->host);
        	}
        }

      } else {
        $content = array(_DELETE_ABORT);
      }
    } else {
      $content = array(_NO_DOMAIN_CHOOSED);
    }
    infoBox($content,$url);
  }
  
  function reset() {
    $dom = $_POST['show'] ? $_POST['show'] : $_GET['show'];
    if (preg_match("/^([0-9a-zA-Z\-]+)\.([0-9a-zA-Z\-]+\.[a-zA-Z\-]+)$/",$dom,$match)) {
      $this->host = $match[1];
      $this->domain = $match[2];
    } else {
      $this->domain = ($_POST['show'] ? $_POST['show'] : $_GET['show']);
      $this->host = "";
    }
    $this->customer = _PHP_AUTH_USER;
    
    $query = "select data from domains where data like '%NameVirtualHost%'";
    list($data) = sql_fetch_row(sql_query($query));
    list(,$ip) = split(" ",$data);
    list($ip,$port) = split(":",$ip);
    $this->virtualHost = $ip;
    $this->port = $port;
    
    $this->serverAdmin = "webmaster@" . $this->domain;
    $this->serverName = "";
    $this->serverAlias = "";

    $webroot = pmwh_getOption('webroot');

    $this->scriptAlias = "/cgi-bin " . $webroot . $this->domain . "/" . $this->host . "/cgi-bin";
    
    $this->documentRoot = $webroot . $this->domain . "/";
    $this->errorLog = "";
    $this->customLog = "";
    $this->transferLog = "";
  }
  
}

?>
